@@ -34,7 +34,7 @@
 #include "vstr.h"
 #include "config.h"
 
-static char gp_title[] = "dvdspanky 1.0.0 - (C) 2007 Jeffrey Grembecki\n\n";
+static char gp_title[] = "dvdspanky 1.0.1 - (C) 2007 Jeffrey Grembecki\n\n";
 static char gp_licence[] =
 "This program is free software; you can redistribute it and/or modify\n"
 "it under the terms of the GNU General Public License as published by\n"
@@ -265,6 +265,12 @@ int encode(video_t *p_in, video_t *p_out, int options, const char *p_filters)
 	vs_cat(p_generic, "transcode -i %s", p_in->p_filename);
 	if(!(options & SPANK_NONICE))
 		vs_cat(p_generic, " --nice 19");
+	if(options & SPANK_MPLAYER)
+	{
+		unlink("stream.yuv");
+		vs_cat(p_generic, " -H 0 -x mplayer,mplayer -g %dx%d -n 0x1 -e %d,%d,%d", p_in->width,
+			p_in->height, p_in->hz,	(p_in->abits) ? p_in->abits : 16, p_in->achans);
+	}
 
 	/* audio */
 	vs_cat(p_audio, " -E 48000,%d,%d -N 0x2000 -b %d",
@@ -283,12 +289,6 @@ int encode(video_t *p_in, video_t *p_out, int options, const char *p_filters)
 		vs_cat(p_video, " -M 0 -J ivtc,32detect=force_mode=3,decimate");
 	if(options & SPANK_FIXNTSC)
 		vs_cat(p_video, " -M 2 -J ivtc,32detect=force_mode=5,decimate --hard_fps");
-	if(options & SPANK_MPLAYER)
-	{
-		unlink("stream.yuv");
-		vs_cat(p_video, " -H 0 -x mplayer,mplayer -g %dx%d -n 0x1 -e %d,%d,%d", p_in->width,
-			p_in->height, p_in->hz,	(p_in->abits) ? p_in->abits : 16, p_in->achans);
-	}
 
 	/* video extra */
 	if(p_out->vcrop || p_out->hcrop)
@@ -361,11 +361,13 @@ int encode(video_t *p_in, video_t *p_out, int options, const char *p_filters)
 			"%s %s -y null,ac3 -m %s-tmp -J astat=%s.norm",
 			p_generic->s, p_audio->s, p_out->p_filename, p_out->p_filename))
 		{
+			print(ML_INFO, "\n");
 			printerror("error scanning volume");
 			unlink(p_final->s);
 			freestrings();
 			return 1;
 		}
+		print(ML_INFO, "\n");
 		unlink(p_final->s);
 		return 0;
 	}
@@ -387,6 +389,7 @@ int encode(video_t *p_in, video_t *p_out, int options, const char *p_filters)
 		{
 			vs_print(p_final, "%s.tmp", p_out->p_filename);
 			unlink(p_final->s);
+			print(ML_INFO, "\n");
 			printerror("transcode failed");
 			freestrings();
 			return 1;
@@ -422,6 +425,10 @@ int encode(video_t *p_in, video_t *p_out, int options, const char *p_filters)
 				return 1;
 			}
 			p_out->volume = atof(p_buffer);
+			if(p_out->volume >= 1.1)
+				p_out->volume -= 0.1;
+			else
+				p_out->volume = 1.0;
 			fclose(p_file);
 		}
 
@@ -447,6 +454,7 @@ int encode(video_t *p_in, video_t *p_out, int options, const char *p_filters)
 			vs_cat(p_final, " -s %f", p_out->volume);
 		if(forkitf(cb_transcode, (void*)p_out, TRANSCODE_BIN, p_final->s))
 		{
+			print(ML_INFO, "\n");
 			printerror("transcode failed");
 			freestrings();
 			return 1;
@@ -464,9 +472,14 @@ int encode(video_t *p_in, video_t *p_out, int options, const char *p_filters)
 			FILE *p_file;
 
 			print(ML_INFO, "scanning volume..\n");
-			forkitf(cb_transcode, (void*)p_out, TRANSCODE_BIN,
+			if(forkitf(cb_transcode, (void*)p_out, TRANSCODE_BIN,
 				"%s %s -y null,ac3 -m %s-tmp -J astat=%s.norm",
-				p_generic->s, p_audio->s, p_out->p_filename, p_out->p_filename);
+				p_generic->s, p_audio->s, p_out->p_filename, p_out->p_filename))
+			{
+				print(ML_INFO, "\n");
+				printerror("error scanning volume");
+			}
+			print(ML_INFO, "\n");
 
 			vs_print(p_final, "%s-tmp.ac3", p_out->p_filename);
 			unlink(p_final->s);
@@ -499,6 +512,7 @@ int encode(video_t *p_in, video_t *p_out, int options, const char *p_filters)
 			vs_cat(p_final, " -s %f", p_out->volume);
 		if(forkit(cb_transcode, (void*)p_out, TRANSCODE_BIN, p_final->s))
 		{
+			print(ML_INFO, "\n");
 			printerror("transcode failed");
 			freestrings();
 			return 2;
@@ -517,6 +531,7 @@ int encode(video_t *p_in, video_t *p_out, int options, const char *p_filters)
 				"mplex -V -f 8 -o %s.mpg %s.m2v %s.ac3",
 				p_out->p_filename, p_out->p_filename, p_out->p_filename))
 				{
+					print(ML_INFO, "\n");
 					printerror("mplex failed");
 					freestrings();
 					return 3;
@@ -528,12 +543,14 @@ int encode(video_t *p_in, video_t *p_out, int options, const char *p_filters)
 				"mplex -f 8 -o %s.mpg %s.m2v %s.ac3",
 				p_out->p_filename, p_out->p_filename, p_out->p_filename))
 			{
+				print(ML_INFO, "\n");
 				printerror("mplex failed");
 				freestrings();
 				return 3;
 			}
 		}
 
+		print(ML_INFO, "\n");
 		vs_print(p_final, "%s.m2v");
 		unlink(p_final->s);
 		vs_print(p_final, "%s.ac3");
